@@ -60,9 +60,9 @@ GType		ephy_spinner_get_type	(void);
 
 GtkWidget      *ephy_spinner_new	(void);
 
-void		ephy_spinner_start	(EphySpinner *throbber);
+void		ephy_spinner_start	(EphySpinner *spinner);
 
-void		ephy_spinner_stop	(EphySpinner *throbber);
+void		ephy_spinner_stop	(EphySpinner *spinner);
 
 void		ephy_spinner_set_size	(EphySpinner *spinner,
 					 GtkIconSize size);
