@@ -15,12 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
 
-#include "ephy-open-tabs-action.h"
+#include <string.h>
+
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include "ephy-bookmarks.h"
 #include "ephy-bookmarks-ui.h"
@@ -28,12 +30,7 @@
 #include "ephy-link-action.h"
 #include "ephy-link.h"
 
-#include <glib/gi18n.h>
-#include <gtk/gtktoolitem.h>
-
-#include <libgnomevfs/gnome-vfs-uri.h>
-
-#include <string.h>
+#include "ephy-open-tabs-action.h"
 
 static void
 activate_cb (GtkAction *action,
